/// <reference types="react" />
import { SearchIndex } from 'algoliasearch';
import { RequestOptions } from '@algolia/transporter';
import { SearchOptions, SearchResponse } from '@algolia/client-search';
/**
 * Creates the Algolia search client and initialises the specified index.
 * @param appId Algolia app ID
 * @param searchKey API key to search this index
 * @param indexName Index to initialise
 */
export declare const createAlgoliaIndex: (appId?: string | undefined, searchKey?: string | undefined, indexName?: string | undefined) => SearchIndex | null;
/** Current request state, hits retrieved, and loading status. */
interface SearchState<Hit> {
    /** Algolia SearchResponse object — contains only last page of hits retrieved */
    response: SearchResponse<Hit> | null;
    /** Contains all hits for search query, including all pages retrieved */
    hits: SearchResponse<Hit>['hits'];
    /** Set when loading initially or loading more hits */
    loading: boolean;
    /** Flag set if there are more pages to be retrieved */
    hasMore: boolean;
    /** Algolia App ID */
    appId: string;
    /** API key to search the index */
    searchKey: string;
    /** Algolia index to query */
    indexName: string;
    /** The Algolia search index created */
    index: SearchIndex | null;
}
/**
 * Hook to make Algolia search queries with built-in support for pagination.
 * @param appId Algolia app ID
 * @param searchKey API key to search the index
 * @param indexName Algolia index to query
 * @param initialRequest Initial `SearchOptions` object sent to Algolia request
 * @returns The following array:
 *   1. `searchState`: containing `hits` and `loading`,
 *   2. `requestDispatch` to update `SearchOptions` passed to Algolia — see
 *      https://www.algolia.com/doc/api-reference/search-api-parameters/, and
 *   3. `getMore` to get the next page of results
 *   4. `setAlgoliaConfig` to update the Algolia index to use
 */
export declare function useAlgolia<Hit = any>(appId: string, searchKey: string, indexName: string, initialRequest?: RequestOptions & SearchOptions): [SearchState<Hit> & {
    request: {
        [x: string]: any;
        cacheable?: boolean | undefined;
        timeout?: number | undefined;
        headers?: Readonly<Record<string, string>> | undefined;
        queryParameters?: Record<string, any> | undefined;
        data?: Record<string, any> | undefined;
        query?: string | undefined;
        similarQuery?: string | undefined;
        facetFilters?: string | readonly string[] | readonly (readonly string[])[] | undefined;
        optionalFilters?: string | readonly string[] | readonly (string | readonly string[])[] | undefined;
        numericFilters?: string | readonly string[] | readonly (readonly string[])[] | undefined;
        tagFilters?: string | readonly string[] | readonly (readonly string[])[] | undefined;
        sumOrFiltersScores?: boolean | undefined;
        filters?: string | undefined;
        page?: number | undefined;
        hitsPerPage?: number | undefined;
        offset?: number | undefined;
        length?: number | undefined;
        attributesToHighlight?: readonly string[] | undefined;
        attributesToSnippet?: readonly string[] | undefined;
        attributesToRetrieve?: readonly string[] | undefined;
        highlightPreTag?: string | undefined;
        highlightPostTag?: string | undefined;
        snippetEllipsisText?: string | undefined;
        restrictHighlightAndSnippetArrays?: boolean | undefined;
        facets?: readonly string[] | undefined;
        maxValuesPerFacet?: number | undefined;
        facetingAfterDistinct?: boolean | undefined;
        minWordSizefor1Typo?: number | undefined;
        minWordSizefor2Typos?: number | undefined;
        allowTyposOnNumericTokens?: boolean | undefined;
        disableTypoToleranceOnAttributes?: readonly string[] | undefined;
        queryType?: "prefixLast" | "prefixAll" | "prefixNone" | undefined;
        removeWordsIfNoResults?: "none" | "lastWords" | "firstWords" | "allOptional" | undefined;
        advancedSyntax?: boolean | undefined;
        advancedSyntaxFeatures?: readonly ("exactPhrase" | "excludeWords")[] | undefined;
        optionalWords?: string | readonly string[] | undefined;
        disableExactOnAttributes?: readonly string[] | undefined;
        exactOnSingleWordQuery?: "none" | "attribute" | "word" | undefined;
        alternativesAsExact?: readonly ("ignorePlurals" | "singleWordSynonym" | "multiWordsSynonym")[] | undefined;
        enableRules?: boolean | undefined;
        ruleContexts?: readonly string[] | undefined;
        distinct?: number | boolean | undefined;
        analytics?: boolean | undefined;
        analyticsTags?: readonly string[] | undefined;
        synonyms?: boolean | undefined;
        replaceSynonymsInHighlight?: boolean | undefined;
        minProximity?: number | undefined;
        responseFields?: readonly string[] | undefined;
        maxFacetHits?: number | undefined;
        percentileComputation?: boolean | undefined;
        clickAnalytics?: boolean | undefined;
        personalizationImpact?: number | undefined;
        enablePersonalization?: boolean | undefined;
        restrictSearchableAttributes?: readonly string[] | undefined;
        sortFacetValuesBy?: "count" | "alpha" | undefined;
        typoTolerance?: boolean | "min" | "strict" | undefined;
        aroundLatLng?: string | undefined;
        aroundLatLngViaIP?: boolean | undefined;
        aroundRadius?: number | "all" | undefined;
        aroundPrecision?: number | readonly {
            readonly from: number;
            readonly value: number;
        }[] | undefined;
        minimumAroundRadius?: number | undefined;
        insideBoundingBox?: readonly (readonly number[])[] | undefined;
        insidePolygon?: readonly (readonly number[])[] | undefined;
        ignorePlurals?: boolean | readonly string[] | undefined;
        removeStopWords?: boolean | readonly string[] | undefined;
        naturalLanguages?: readonly string[] | undefined;
        getRankingInfo?: boolean | undefined;
        userToken?: string | undefined;
        enableABTest?: boolean | undefined;
        decompoundQuery?: boolean | undefined;
        relevancyStrictness?: number | undefined;
    };
}, import("react").Dispatch<RequestOptions & SearchOptions>, () => void, (newConfig: Partial<Pick<SearchState<Hit>, 'appId' | 'searchKey' | 'indexName'>>) => void, (page?: number | undefined) => Promise<void>];
export default useAlgolia;
